CannyEdgeDetectorExt

Trait CannyEdgeDetectorExt 

pub trait CannyEdgeDetectorExt<T> {
    type Output;

    // Required method
    fn canny_edge_detector(
        &self,
        params: CannyParameters<T>,
    ) -> Result<Self::Output, Error>;
}
Runs the Canny Edge Detector algorithm on a type T

Required Associated Types

type Output

Output type, this is different as canny outputs a binary image

Required Methods

fn canny_edge_detector( &self, params: CannyParameters<T>, ) -> Result<Self::Output, Error>

Run the edge detection algorithm with the given parameters. Due to Canny being specified as working on greyscale images all current implementations assume a single channel image returning an error otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, U> CannyEdgeDetectorExt<T> for ArrayBase<U, Ix3>
where U: DataMut<Elem = T>, T: Copy + Clone + FromPrimitive + Real + Num + NumAssignOps,

Implementors

Source

impl<T, U, C> CannyEdgeDetectorExt<T> for ImageBase<U, C>
where U: DataMut<Elem = T>, T: Copy + Clone + FromPrimitive + Real + Num + NumAssignOps, C: ColourModel,