Module kernels

Module kernels 

Common convolution kernels and traits to aid in the building of kernels

Structs

BoxLinearFilter
The box linear filter is roughly defined as 1/(R*C)*Array2::ones((R, C)) This filter will be a box linear for every colour channel provided
GaussianFilter
Builds a Gaussian kernel taking the covariance as a parameter. Covariance is given as 2 values for the x and y variance.
LaplaceFilter
Create a Laplacian filter, this provides the 2nd spatial derivative of an image.
SobelFilter
Builder to create either a horizontal or vertical Sobel filter for the Sobel operator

Enums

LaplaceType
Specifies the type of Laplacian filter
Orientation
Orientation of the filter

Traits

FixedDimensionKernelBuilder
Create a kernel with a fixed dimension
KernelBuilder
Builds a convolutioon kernel given a shape and optional parameters