ThresholdMeanExt

Trait ThresholdMeanExt 

pub trait ThresholdMeanExt<T> {
    type Output;

    // Required method
    fn threshold_mean(&self) -> Result<Self::Output, Error>;
}
Runs the Mean thresholding algorithm on a type T.

Required Associated Types

type Output

The Mean thresholding output is a binary image.

Required Methods

fn threshold_mean(&self) -> Result<Self::Output, Error>

Run the Mean threshold algorithm.

This assumes the image is a single channel image, i.e., a greyscale image; otherwise, an error is returned.

Errors

Returns a ChannelDimensionMismatch error if more than one channel exists.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, U> ThresholdMeanExt<T> for ArrayBase<U, Ix3>
where U: Data<Elem = T>, T: Copy + Clone + Ord + Num + NumAssignOps + ToPrimitive + FromPrimitive,

Implementors

Source

impl<T, U, C> ThresholdMeanExt<T> for ImageBase<U, C>
where U: Data<Elem = T>, Image<U, C>: Clone, T: Copy + Clone + Ord + Num + NumAssignOps + ToPrimitive + FromPrimitive + PixelBound, C: ColourModel,